From 49b051bd3ada7b25096c91299ad432dad33ec023 Mon Sep 17 00:00:00 2001
From: Holger Hans Peter Freyther <zecke@selfish.org>
Date: Mon, 21 Sep 2009 22:48:25 +0200
Subject: [PATCH 2/4] network: Add direct access to the RawHeader

Provide direct access to the header fields. This makes
QNetworkReplyHandler::sendResponseIfNedded drop out of
the profile on the loading_standalone test case.
---
 src/network/access/qnetworkreply.cpp |    6 ++++++
 src/network/access/qnetworkreply.h   |    3 +++
 2 files changed, 9 insertions(+), 0 deletions(-)

diff --git a/src/network/access/qnetworkreply.cpp b/src/network/access/qnetworkreply.cpp
index 4eb53bf..7acd3bb 100644
--- a/src/network/access/qnetworkreply.cpp
+++ b/src/network/access/qnetworkreply.cpp
@@ -529,6 +529,12 @@ QByteArray QNetworkReply::rawHeader(const QByteArray &headerName) const
     return QByteArray();
 }
 
+const QList<QNetworkReply::RawHeaderPair>& QNetworkReply::rawHeaderPairs() const
+{
+    Q_D(const QNetworkReply);
+    return d->rawHeaders;
+}
+
 /*!
     Returns a list of headers fields that were sent by the remote
     server, in the order that they were sent. Duplicate headers are
diff --git a/src/network/access/qnetworkreply.h b/src/network/access/qnetworkreply.h
index c624810..82086c4 100644
--- a/src/network/access/qnetworkreply.h
+++ b/src/network/access/qnetworkreply.h
@@ -128,6 +128,9 @@ public:
     QList<QByteArray> rawHeaderList() const;
     QByteArray rawHeader(const QByteArray &headerName) const;
 
+    typedef QPair<QByteArray, QByteArray> RawHeaderPair;
+    const QList<RawHeaderPair>& rawHeaderPairs() const;
+
     // attributes
     QVariant attribute(QNetworkRequest::Attribute code) const;
 
-- 
1.6.3.3

